@@ -1,6 +1,6 @@
 package api
 
-import "github.com/xanzy/go-gitlab"
+import gitlab "gitlab.com/gitlab-org/api/client-go"
 
 var GetCommitStatuses = func(client *gitlab.Client, pid interface{}, sha string) ([]*gitlab.CommitStatus, error) {
 	if client == nil {
@@ -8,7 +8,7 @@ var GetCommitStatuses = func(client *gitlab.Client, pid interface{}, sha string)
 	}
 
 	opt := &gitlab.GetCommitStatusesOptions{
-		All: gitlab.Bool(true),
+		All: gitlab.Ptr(true),
 	}
 
 	statuses, _, err := client.Commits.GetCommitStatuses(pid, sha, opt, nil)
