@@ -6,7 +6,8 @@ import (
 	"io"
 	"sort"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
+	"gitlab.com/gitlab-org/cli/pkg/dbg"
 	"gitlab.com/gitlab-org/cli/pkg/git"
 )
 
@@ -120,6 +121,7 @@ var GetLastPipeline = func(client *gitlab.Client, repo string, ref string) (*git
 
 	c, _, err := client.Commits.GetCommit(repo, ref, nil)
 	if err != nil {
+		dbg.Debug("go-client GetCommit error:", err.Error())
 		return nil, err
 	}
 	if c.LastPipeline != nil {
@@ -129,11 +131,12 @@ var GetLastPipeline = func(client *gitlab.Client, repo string, ref string) (*git
 	l := &gitlab.ListProjectPipelinesOptions{
 		Ref:  gitlab.Ptr(ref),
 		Sort: gitlab.Ptr("desc"),
+		ListOptions: gitlab.ListOptions{
+			Page:    1,
+			PerPage: 1,
+		},
 	}
 
-	l.Page = 1
-	l.PerPage = 1
-
 	pipes, err := GetPipelines(client, l, repo)
 	if err != nil {
 		return nil, err
@@ -256,12 +259,7 @@ var GetPipelineFromBranch = func(client *gitlab.Client, ref, repo string) ([]*gi
 			return nil, err
 		}
 	}
-	l := &gitlab.ListProjectPipelinesOptions{
-		Ref:  gitlab.Ptr(ref),
-		Sort: gitlab.Ptr("desc"),
-	}
-	l.Page = 1
-	l.PerPage = 1
+
 	pipeline, err := GetLastPipeline(client, repo, ref)
 	if err != nil {
 		return nil, err
