@@ -153,7 +153,16 @@ func main() {
 	rootCmd.SetArgs(expandedArgs)
 
 	if cmd, err := rootCmd.ExecuteC(); err != nil {
-		printError(cmdFactory.IO, err, cmd, debug, true)
+		if !errors.Is(err, cmdutils.SilentError) {
+			printError(cmdFactory.IO, err, cmd, debug)
+		}
+
+		var exitError *cmdutils.ExitError
+		if errors.As(err, &exitError) {
+			os.Exit(exitError.Code)
+		} else {
+			os.Exit(1)
+		}
 	}
 
 	if help.HasFailed() {
@@ -173,20 +182,16 @@ func main() {
 
 		err = update.CheckUpdate(cmdFactory, version, true, argCommand)
 		if err != nil {
-			printError(cmdFactory.IO, err, rootCmd, debug, false)
+			printError(cmdFactory.IO, err, rootCmd, debug)
 		}
 	}
 
 	api.GetClient().HTTPClient().CloseIdleConnections()
 }
 
-func printError(streams *iostreams.IOStreams, err error, cmd *cobra.Command, debug, shouldExit bool) {
-	if errors.Is(err, cmdutils.SilentError) {
-		return
-	}
+func printError(streams *iostreams.IOStreams, err error, cmd *cobra.Command, debug bool) {
 	color := streams.Color()
 	printMore := true
-	exitCode := 1
 
 	var dnsError *net.DNSError
 	if errors.As(err, &dnsError) {
@@ -201,7 +206,6 @@ func printError(streams *iostreams.IOStreams, err error, cmd *cobra.Command, deb
 		var exitError *cmdutils.ExitError
 		if errors.As(err, &exitError) {
 			streams.Logf("%s %s %s=%s\n", color.FailedIcon(), color.Bold(exitError.Details), color.Red("error"), exitError.Err)
-			exitCode = exitError.Code
 			printMore = false
 		}
 
@@ -221,9 +225,6 @@ func printError(streams *iostreams.IOStreams, err error, cmd *cobra.Command, deb
 	if cmd != nil {
 		cmd.Print("\n")
 	}
-	if shouldExit {
-		os.Exit(exitCode)
-	}
 }
 
 func maybeOverrideDefaultHost(f *cmdutils.Factory, cfg config.Config) {
