@@ -1,13 +1,12 @@
 package alias
 
 import (
-	"bytes"
-	"io"
 	"os"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
+	"gitlab.com/gitlab-org/cli/test"
 )
 
 func Test_Alias(t *testing.T) {
@@ -17,18 +16,7 @@ func Test_Alias(t *testing.T) {
 
 	assert.Nil(t, NewCmdAlias(&cmdutils.Factory{}).Execute())
 
-	outC := make(chan string)
-	// copy the output in a separate goroutine so printing can't block indefinitely
-	go func() {
-		var buf bytes.Buffer
-		_, _ = io.Copy(&buf, r)
-		outC <- buf.String()
-	}()
-
-	// back to normal state
-	w.Close()
-	os.Stdout = old // restoring the real stdout
-	out := <-outC
+	out := test.ReturnBuffer(old, r, w)
 
 	assert.Contains(t, out, "Use \"alias [command] --help\" for more information about a command.\n")
 }
