@@ -11,18 +11,24 @@ import (
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/pkg/git"
 
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 )
 
+var (
+	ref         string
+	dryRun      bool
+	includeJobs bool
+)
+
 func NewCmdLint(f *cmdutils.Factory) *cobra.Command {
 	pipelineCILintCmd := &cobra.Command{
 		Use:   "lint",
 		Short: "Checks if your `.gitlab-ci.yml` file is valid.",
 		Args:  cobra.MaximumNArgs(1),
 		Example: heredoc.Doc(`
-		$ glab ci lint
 		# Uses .gitlab-ci.yml in the current directory
+		$ glab ci lint
 
 		$ glab ci lint .gitlab-ci.yml
 
@@ -37,6 +43,10 @@ func NewCmdLint(f *cmdutils.Factory) *cobra.Command {
 		},
 	}
 
+	pipelineCILintCmd.Flags().BoolVarP(&dryRun, "dry-run", "", false, "Run pipeline creation simulation.")
+	pipelineCILintCmd.Flags().BoolVarP(&includeJobs, "include-jobs", "", false, "Response includes the list of jobs that would exist in a static check or pipeline simulation.")
+	pipelineCILintCmd.Flags().StringVar(&ref, "ref", "", "When 'dry-run' is true, sets the branch or tag context for validating the CI/CD YAML configuration.")
+
 	return pipelineCILintCmd
 }
 
@@ -52,12 +62,12 @@ func lintRun(f *cmdutils.Factory, path string) error {
 
 	repo, err := f.BaseRepo()
 	if err != nil {
-		return fmt.Errorf("You need to be in a GitLab project repository for this action.\nError: %s", err)
+		return fmt.Errorf("You must be in a GitLab project repository for this action.\nError: %s", err)
 	}
 
 	project, err := repo.Project(apiClient)
 	if err != nil {
-		return fmt.Errorf("You need to be in a GitLab project repository for this action.\nError: %s", err)
+		return fmt.Errorf("You must be in a GitLab project repository for this action.\nError: %s", err)
 	}
 
 	projectID := project.ID
@@ -79,7 +89,7 @@ func lintRun(f *cmdutils.Factory, path string) error {
 		content, err = os.ReadFile(path)
 		if err != nil {
 			if os.IsNotExist(err) {
-				return fmt.Errorf("%s: no such file or directory", path)
+				return fmt.Errorf("%s: no such file or directory.", path)
 			}
 			return err
 		}
@@ -87,19 +97,18 @@ func lintRun(f *cmdutils.Factory, path string) error {
 
 	fmt.Fprintln(f.IO.StdOut, "Validating...")
 
-	lint, err := api.ProjectNamespaceLint(apiClient, projectID, string(content))
+	lint, err := api.ProjectNamespaceLint(apiClient, projectID, string(content), ref, dryRun, includeJobs)
 	if err != nil {
 		return err
 	}
 
 	if !lint.Valid {
-		fmt.Fprintln(out, c.Red(path+" is invalid"))
+		fmt.Fprintln(out, c.Red(path+" is invalid."))
 		for i, err := range lint.Errors {
 			i++
 			fmt.Fprintln(out, i, err)
 		}
-		// Returning the error to cobra here causes the process to exit with code 0, so we exit manually.
-		os.Exit(1)
+		return cmdutils.SilentError
 	}
 	fmt.Fprintln(out, c.GreenCheck(), "CI/CD YAML is valid!")
 	return nil
