@@ -3,6 +3,7 @@ package note
 import (
 	"fmt"
 	"net/http"
+	"os"
 	"reflect"
 	"testing"
 
@@ -207,7 +208,12 @@ func Test_IssuableNoteCreate_prompt(t *testing.T) {
 			}
 			assert.Equal(t, "", output.Stderr())
 			assert.Equal(t, "https://gitlab.com/OWNER/REPO/issues/1#note_301\n", output.String())
-			assert.Equal(t, "vi", actualEditor)
+
+			editor := os.Getenv("EDITOR")
+			if editor == "" {
+				editor = "vi"
+			}
+			assert.Equal(t, editor, actualEditor)
 		})
 
 		tests := []struct {
