@@ -6,7 +6,7 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/prompt"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
@@ -46,7 +46,7 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			}
 
 			opts := &gitlab.CreateIssueBoardOptions{
-				Name: gitlab.String(boardName),
+				Name: gitlab.Ptr(boardName),
 			}
 
 			fmt.Fprintln(out, "- Creating board")
