@@ -10,7 +10,7 @@ import (
 	"github.com/gdamore/tcell/v2"
 	"github.com/rivo/tview"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
@@ -186,11 +186,11 @@ func NewCmdView(f *cmdutils.Factory) *cobra.Command {
 	}
 
 	viewCmd.Flags().
-		StringVarP(&opts.assignee, "assignee", "a", "", "Filter board issues by assignee username")
+		StringVarP(&opts.assignee, "assignee", "a", "", "Filter board issues by assignee username.")
 	viewCmd.Flags().
-		StringSliceVarP(&opts.labels, "labels", "l", []string{}, "Filter board issues by labels (comma separated)")
+		StringSliceVarP(&opts.labels, "labels", "l", []string{}, "Filter board issues by labels, comma separated.")
 	viewCmd.Flags().
-		StringVarP(&opts.milestone, "milestone", "m", "", "Filter board issues by milestone")
+		StringVarP(&opts.milestone, "milestone", "m", "", "Filter board issues by milestone.")
 	return viewCmd
 }
 
@@ -429,7 +429,7 @@ func getGroupBoardIssues(groupID int, opts *issueBoardViewOptions) ([]*gitlab.Is
 
 func getProjectBoardIssues(opts *issueBoardViewOptions) ([]*gitlab.Issue, error) {
 	reqOpts := opts.getListProjectIssueOptions()
-	issues, err := api.ListIssues(apiClient, repo.FullName(), reqOpts)
+	issues, err := api.ListProjectIssues(apiClient, repo.FullName(), reqOpts)
 	if err != nil {
 		return nil, fmt.Errorf("retrieving list issues: %w", err)
 	}
