@@ -17,7 +17,7 @@ import (
 	"github.com/acarl005/stripansi"
 	"github.com/pkg/errors"
 	"github.com/stretchr/testify/assert"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 )
