@@ -21,7 +21,7 @@ import (
 	"gitlab.com/gitlab-org/cli/internal/recovery"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/commands/mr/mrutils"
@@ -79,7 +79,7 @@ type CreateOpts struct {
 	TargetProject *gitlab.Project `json:"target_project,omitempty"`
 }
 
-func NewCmdCreate(f *cmdutils.Factory, runE func(opts *CreateOpts) error) *cobra.Command {
+func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 	opts := &CreateOpts{
 		IO:       f.IO,
 		Branch:   f.Branch,
@@ -149,10 +149,6 @@ func NewCmdCreate(f *cmdutils.Factory, runE func(opts *CreateOpts) error) *cobra
 				return &cmdutils.FlagError{Err: errors.New("--copy-issue-labels can only be used with --related-issue.")}
 			}
 
-			if runE != nil {
-				return runE(opts)
-			}
-
 			if err := createRun(opts); err != nil {
 				// always save options to file
 				recoverErr := createRecoverSaveFile(opts)
