@@ -17,7 +17,7 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/utils"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 type ListOptions struct {
@@ -35,11 +35,12 @@ type ListOptions struct {
 	Group        string
 
 	// issue states
-	State  string
-	Closed bool
-	Merged bool
-	All    bool
-	Draft  bool
+	State    string
+	Closed   bool
+	Merged   bool
+	All      bool
+	Draft    bool
+	NotDraft bool
 
 	// Pagination
 	Page         int
@@ -50,6 +51,10 @@ type ListOptions struct {
 	ListType       string
 	TitleQualifier string
 
+	// sort options
+	Sort    string
+	OrderBy string
+
 	IO         *iostreams.IOStreams
 	BaseRepo   func() (glrepo.Interface, error)
 	HTTPClient func() (*gitlab.Client, error)
@@ -76,6 +81,8 @@ func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 			glab mr list --label needs-review
 			glab mr list --not-label waiting-maintainer-feedback,subsystem-x
 			glab mr list -M --per-page 10
+			glab mr list --draft
+			glab mr list --not-draft
 		`),
 		Args: cobra.ExactArgs(0),
 		RunE: func(cmd *cobra.Command, args []string) error {
@@ -134,11 +141,14 @@ func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 	mrListCmd.Flags().BoolVarP(&opts.Closed, "closed", "c", false, "Get only closed merge requests.")
 	mrListCmd.Flags().BoolVarP(&opts.Merged, "merged", "M", false, "Get only merged merge requests.")
 	mrListCmd.Flags().BoolVarP(&opts.Draft, "draft", "d", false, "Filter by draft merge requests.")
+	mrListCmd.Flags().BoolVarP(&opts.NotDraft, "not-draft", "", false, "Filter by non-draft merge requests.")
 	mrListCmd.Flags().StringVarP(&opts.OutputFormat, "output", "F", "text", "Format output as: text, json.")
 	mrListCmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number.")
 	mrListCmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 30, "Number of items to list per page.")
 	mrListCmd.Flags().StringSliceVarP(&opts.Assignee, "assignee", "a", []string{}, "Get only merge requests assigned to users.")
 	mrListCmd.Flags().StringSliceVarP(&opts.Reviewer, "reviewer", "r", []string{}, "Get only merge requests with users as reviewer.")
+	mrListCmd.Flags().StringVarP(&opts.Sort, "sort", "S", "", "Sort merge requests by <field>. Sort options: asc, desc.")
+	mrListCmd.Flags().StringVarP(&opts.OrderBy, "order", "o", "", "Order merge requests by <field>. Order options: created_at, title, merged_at or updated_at.")
 
 	mrListCmd.Flags().BoolP("opened", "O", false, "Get only open merge requests.")
 	_ = mrListCmd.Flags().MarkHidden("opened")
@@ -148,6 +158,7 @@ func NewCmdList(f *cmdutils.Factory, runE func(opts *ListOptions) error) *cobra.
 	_ = mrListCmd.Flags().MarkHidden("mine")
 	_ = mrListCmd.Flags().MarkDeprecated("mine", "use --assignee=@me.")
 	mrListCmd.PersistentFlags().StringP("group", "g", "", "Select a group/subgroup. This option is ignored if a repo argument is set.")
+	mrListCmd.MarkFlagsMutuallyExclusive("draft", "not-draft")
 
 	return mrListCmd
 }
@@ -167,14 +178,15 @@ func listRun(opts *ListOptions) error {
 
 	l := &gitlab.ListProjectMergeRequestsOptions{
 		State: gitlab.Ptr(opts.State),
+		ListOptions: gitlab.ListOptions{
+			Page:    1,
+			PerPage: 30,
+		},
 	}
 	jsonOutput := opts.OutputFormat == "json"
 	if jsonOutput {
 		l.Page = 0
 		l.PerPage = 0
-	} else {
-		l.Page = 1
-		l.PerPage = 30
 	}
 
 	if opts.Author != "" {
@@ -219,12 +231,25 @@ func listRun(opts *ListOptions) error {
 		l.WIP = gitlab.Ptr("yes")
 		opts.ListType = "search"
 	}
+	if opts.NotDraft {
+		l.WIP = gitlab.Ptr("no")
+		opts.ListType = "search"
+	}
 
 	if opts.Mine {
 		l.Scope = gitlab.Ptr("assigned_to_me")
 		opts.ListType = "search"
 	}
 
+	if opts.OrderBy != "" {
+		l.OrderBy = gitlab.Ptr(opts.OrderBy)
+		opts.ListType = "search"
+	}
+
+	if opts.Sort != "" {
+		l.Sort = gitlab.Ptr(opts.Sort)
+	}
+
 	assigneeIds := make([]int, 0)
 	if len(opts.Assignee) > 0 {
 		users, err := api.UsersByNames(apiClient, opts.Assignee)
