@@ -8,9 +8,10 @@ import (
 	"strconv"
 	"strings"
 
+	"gitlab.com/gitlab-org/cli/pkg/dbg"
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
@@ -55,6 +56,13 @@ func MRCheckErrors(mr *gitlab.MergeRequest, err MRCheckErrOptions) error {
 		return fmt.Errorf("this merge request is still a draft. Run `glab mr update %d --ready` to mark it as ready for review.", mr.IID)
 	}
 
+	dbg.Debug("MergeWhenPipelineSucceeds:", strconv.FormatBool(mr.MergeWhenPipelineSucceeds))
+	dbg.Debug("DetailedMergeStatus:", mr.DetailedMergeStatus)
+
+	if mr.DetailedMergeStatus == "ci_must_pass" {
+		return fmt.Errorf("this merge request requires a passing pipeline before merging.")
+	}
+
 	if mr.MergeWhenPipelineSucceeds && err.PipelineStatus && mr.Pipeline != nil {
 		if mr.Pipeline.Status != "success" {
 			return fmt.Errorf("the pipeline for this merge request has failed. The pipeline must succeed before merging.")
