@@ -2,7 +2,7 @@ package rebase
 
 import (
 	"github.com/MakeNowJust/heredoc/v2"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/commands/mr/mrutils"
 
