@@ -14,7 +14,7 @@ import (
 
 	"github.com/acarl005/stripansi"
 	"github.com/stretchr/testify/require"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/config"
@@ -318,7 +318,7 @@ func Test_rawMRPreview(t *testing.T) {
 				"--",
 				"MR description",
 				"\n--\ncomments/notes:\n",
-				"There are no comments on this merge request",
+				"There are no comments on this merge request.",
 			},
 		},
 		{
