@@ -11,11 +11,12 @@ import (
 	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
 	"github.com/spf13/pflag"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/api"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/config"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
+	"gitlab.com/gitlab-org/cli/pkg/dbg"
 	"gitlab.com/gitlab-org/cli/pkg/git"
 	"gitlab.com/gitlab-org/cli/pkg/glinstance"
 )
@@ -54,14 +55,16 @@ type ContextOpts struct {
 
 func NewCmdClone(f *cmdutils.Factory, runE func(*CloneOptions, *ContextOpts) error) *cobra.Command {
 	opts := &CloneOptions{
-		IO:     f.IO,
-		Config: f.Config,
+		GitFlags: []string{},
+		IO:       f.IO,
+		Config:   f.Config,
 	}
 
 	ctxOpts := &ContextOpts{}
 
 	repoCloneCmd := &cobra.Command{
-		Use:   "clone <repo> [flags] [<dir>] [-- [<gitflags>...]]",
+		Use: `clone <repo> [flags] [<dir>] [-- <gitflags>...]
+glab repo clone -g <group> [flags] [<dir>] [-- <gitflags>...]`,
 		Short: `Clone a GitLab repository or project.`,
 		Example: heredoc.Doc(`
 	$ glab repo clone profclems/glab
@@ -95,13 +98,20 @@ func NewCmdClone(f *cmdutils.Factory, runE func(*CloneOptions, *ContextOpts) err
 		- project ID
 	`),
 		RunE: func(cmd *cobra.Command, args []string) error {
+			// Move arguments after "--" to gitFlags
+			if dashPos := cmd.ArgsLenAtDash(); dashPos != -1 {
+				opts.GitFlags = args[dashPos:]
+				args = args[:dashPos]
+			}
+			dbg.Debug("Args:", strings.Join(args, " "))
+			dbg.Debug("GitFlags:", strings.Join(opts.GitFlags, " "))
 			if nArgs := len(args); nArgs > 0 {
 				ctxOpts.Repo = args[0]
 				if nArgs > 1 && !opts.PreserveNamespace {
 					opts.Dir = args[1]
 				}
-				opts.GitFlags = args[1:]
 			}
+			dbg.Debug("Dir:", opts.Dir)
 
 			if ctxOpts.Repo == "" && opts.GroupName == "" {
 				return &cmdutils.FlagError{Err: fmt.Errorf("Specify repository argument, or use the --group flag to specify a group to clone all repos from the group.")}
@@ -266,15 +276,11 @@ func cloneRun(opts *CloneOptions, ctxOpts *ContextOpts) (err error) {
 		ctxOpts.Repo += ".git"
 	}
 	// To preserve namespaces, we deep copy gitFlags for group clones
-	var gitFlags []string
 	if opts.PreserveNamespace {
 		namespacedDir := ctxOpts.Project.PathWithNamespace
 		opts.Dir = namespacedDir
-		gitFlags = append([]string{namespacedDir}, opts.GitFlags...)
-	} else {
-		gitFlags = opts.GitFlags
 	}
-	_, err = git.RunClone(ctxOpts.Repo, gitFlags)
+	_, err = git.RunClone(ctxOpts.Repo, opts.Dir, opts.GitFlags)
 	if err != nil {
 		return
 	}
