@@ -5,9 +5,9 @@ import (
 
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
-	"github.com/MakeNowJust/heredoc"
+	"github.com/MakeNowJust/heredoc/v2"
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 	"gitlab.com/gitlab-org/cli/internal/glrepo"
 	"gitlab.com/gitlab-org/cli/pkg/tableprinter"
@@ -35,8 +35,8 @@ func NewCmdContributors(f *cmdutils.Factory) *cobra.Command {
 		Example: heredoc.Doc(`
 	$ glab repo contributors
 
+	# Supports overriding the repository.
 	$ glab repo contributors -R gitlab-com/www-gitlab-com
-	# Supports repo override
 	`),
 		Args:    cobra.ExactArgs(0),
 		Aliases: []string{"users"},
@@ -51,9 +51,9 @@ func NewCmdContributors(f *cmdutils.Factory) *cobra.Command {
 
 	cmdutils.EnableRepoOverride(repoContributorsCmd, f)
 
-	repoContributorsCmd.Flags().StringVarP(&opts.OrderBy, "order", "o", "commits", "Return contributors ordered by name, email, or commits (orders by commit date) fields")
-	repoContributorsCmd.Flags().StringVarP(&opts.Sort, "sort", "s", "", "Return contributors sorted in asc or desc order")
-	repoContributorsCmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number")
+	repoContributorsCmd.Flags().StringVarP(&opts.OrderBy, "order", "o", "commits", "Return contributors ordered by name, email, or commits (orders by commit date) fields.")
+	repoContributorsCmd.Flags().StringVarP(&opts.Sort, "sort", "s", "", "Return contributors. Sort options: asc, desc.")
+	repoContributorsCmd.Flags().IntVarP(&opts.Page, "page", "p", 1, "Page number.")
 	repoContributorsCmd.Flags().IntVarP(&opts.PerPage, "per-page", "P", 30, "Number of items to list per page.")
 	return repoContributorsCmd
 }
@@ -77,13 +77,16 @@ func runE(opts *Options) error {
 	}
 
 	l := &gitlab.ListContributorsOptions{
-		OrderBy: gitlab.String(opts.OrderBy),
+		OrderBy: gitlab.Ptr(opts.OrderBy),
+		ListOptions: gitlab.ListOptions{
+			Page:    opts.Page,
+			PerPage: opts.PerPage,
+		},
 	}
+
 	if opts.Sort != "" {
-		l.Sort = gitlab.String(opts.Sort)
+		l.Sort = gitlab.Ptr(opts.Sort)
 	}
-	l.PerPage = opts.PerPage
-	l.Page = opts.Page
 
 	users, _, err := apiClient.Repositories.Contributors(repo.FullName(), l)
 	if err != nil {
