@@ -10,6 +10,8 @@ import (
 	"strings"
 	"time"
 
+	securejoin "github.com/cyphar/filepath-securejoin"
+	catalog "gitlab.com/gitlab-org/cli/commands/release/create/catalog"
 	"gitlab.com/gitlab-org/cli/commands/release/releaseutils"
 	"gitlab.com/gitlab-org/cli/commands/release/releaseutils/upload"
 
@@ -26,21 +28,25 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/iostreams"
 
 	"github.com/spf13/cobra"
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 )
 
 type CreateOpts struct {
-	Name             string
-	Ref              string
-	TagName          string
-	TagMessage       string
-	Notes            string
-	NotesFile        string
-	Milestone        []string
-	AssetLinksAsJson string
-	ReleasedAt       string
-	RepoOverride     string
+	Name                        string
+	Ref                         string
+	TagName                     string
+	TagMessage                  string
+	Notes                       string
+	NotesFile                   string
+	ExperimentalNotesTextOrFile string
+	Milestone                   []string
+	AssetLinksAsJson            string
+	ReleasedAt                  string
+	RepoOverride                string
+	PublishToCatalog            bool
+	NoUpdate                    bool
+	NoCloseMilestone            bool
 
 	NoteProvided       bool
 	ReleaseNotesAction string
@@ -77,12 +83,12 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 
 		To fetch the new tag locally after the release, run %[1]sgit fetch --tags origin%[1]s.
 		`, "`"),
-		Args: cmdutils.MinimumArgs(1, "no tag name provided"),
-		Example: heredoc.Doc(`
-			# Interactively create a release
+		Args: cmdutils.MinimumArgs(1, "no tag name provided."),
+		Example: heredoc.Docf(`
+			# Create a release interactively
 			$ glab release create v1.0.1
 
-			# Non-interactively create a release by specifying a note
+			# Create a release non-interactively by specifying a note
 			$ glab release create v1.0.1 --notes "bugfix release"
 
 			# Use release notes from a file
@@ -94,10 +100,10 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			# Upload a release asset with a display name and type
 			$ glab release create v1.0.1 '/path/to/asset.png#My display label#image'
 
-			# Upload all assets in a specified folder (types will default to 'other')
+			# Upload all assets in a specified folder (types default to 'other')
 			$ glab release create v1.0.1 ./dist/*
 
-			# Upload all tarballs in a specified folder (types will default to 'other')
+			# Upload all tarballs in a specified folder (types default to 'other')
 			$ glab release create v1.0.1 ./dist/*.tar.gz
 
 			# Create a release with assets specified as JSON object
@@ -110,7 +116,27 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 			      "direct_asset_path": "path/to/file"
 			    }
 			  ]'
-`),
+
+			# [EXPERIMENTAL] Create a release and publish it to the GitLab CI/CD catalog
+			# Requires the feature flag %[1]sci_release_cli_catalog_publish_option%[1]s to be enabled
+			# for this project in your GitLab instance. Do NOT run this manually. Use it as part
+			# of a CI/CD pipeline with the "release" keyword:
+			#
+			# - The API endpoint accepts only "CI_JOB_TOKEN" as the authentication token.
+			# - It retrieves components from the current repository by searching for
+			#   %[1]syml%[1]s files within the "templates" directory and its subdirectories.
+			# - It fails if the feature flag %[1]sci_release_cli_catalog_publish_option%[1]s
+			#   is not enabled for this project in your GitLab instance.
+
+			# Components can be defined:
+
+			# - In single files ending in %[1]s.yml%[1]s for each component, like %[1]stemplates/secret-detection.yml%[1]s.
+			# - In subdirectories containing %[1]stemplate.yml%[1]s files as entry points,
+			#   for components that bundle together multiple related files. For example,
+			#   %[1]stemplates/secret-detection/template.yml%[1]s.
+
+			$ glab release create v1.0.1 --publish-to-catalog
+`, "`"),
 		RunE: func(cmd *cobra.Command, args []string) error {
 			var err error
 			opts.RepoOverride, _ = cmd.Flags().GetString("repo")
@@ -131,24 +157,11 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 				}
 			}
 
-			opts.NoteProvided = cmd.Flags().Changed("notes")
-			if opts.NotesFile != "" {
-				var b []byte
-				var err error
-				if opts.NotesFile == "-" {
-					b, err = io.ReadAll(opts.IO.In)
-					_ = opts.IO.In.Close()
-				} else {
-					b, err = os.ReadFile(opts.NotesFile)
-				}
-
-				if err != nil {
-					return err
-				}
-
-				opts.Notes = string(b)
-				opts.NoteProvided = true
+			opts.Notes, err = resolveNotes(cmd, opts)
+			if err != nil {
+				return err
 			}
+			opts.NoteProvided = opts.Notes != ""
 
 			return createRun(opts)
 		},
@@ -162,10 +175,81 @@ func NewCmdCreate(f *cmdutils.Factory) *cobra.Command {
 	cmd.Flags().StringVarP(&opts.ReleasedAt, "released-at", "D", "", "The 'date' when the release was ready. Defaults to the current datetime. Expects ISO 8601 format (2019-03-15T08:00:00Z).")
 	cmd.Flags().StringSliceVarP(&opts.Milestone, "milestone", "m", []string{}, "The title of each milestone the release is associated with.")
 	cmd.Flags().StringVarP(&opts.AssetLinksAsJson, "assets-links", "a", "", "'JSON' string representation of assets links, like `--assets-links='[{\"name\": \"Asset1\", \"url\":\"https://<domain>/some/location/1\", \"link_type\": \"other\", \"direct_asset_path\": \"path/to/file\"}]'.`")
+	cmd.Flags().BoolVar(&opts.PublishToCatalog, "publish-to-catalog", false, "[EXPERIMENTAL] Publish the release to the GitLab CI/CD catalog.")
+	cmd.Flags().BoolVar(&opts.NoUpdate, "no-update", false, "Prevent updating the existing release.")
+	cmd.Flags().BoolVar(&opts.NoCloseMilestone, "no-close-milestone", false, "Prevent closing milestones after creating the release.")
+	cmd.Flags().StringVar(&opts.ExperimentalNotesTextOrFile, "experimental-notes-text-or-file", "", "[EXPERIMENTAL] Value to use as release notes. If a file exists with this value as path, its content will be used. Otherwise, the value itself will be used as text.")
+	_ = cmd.Flags().MarkHidden("experimental-notes-text-or-file")
+
+	// These two need to be separately exclusive to avoid a breaking change
+	// because there may be existing scripts that already use both notes and notes-file.
+	cmd.MarkFlagsMutuallyExclusive("experimental-notes-text-or-file", "notes")
+	cmd.MarkFlagsMutuallyExclusive("experimental-notes-text-or-file", "notes-file")
 
 	return cmd
 }
 
+func resolveNotes(cmd *cobra.Command, opts *CreateOpts) (string, error) {
+	if cmd.Flags().Changed("notes") {
+		return opts.Notes, nil
+	}
+
+	if opts.NotesFile != "" {
+		return resolveNotesFile(opts)
+	}
+
+	if opts.ExperimentalNotesTextOrFile != "" {
+		return resolveNotesFileOrText(opts)
+	}
+
+	return "", nil
+}
+
+func resolveNotesFile(opts *CreateOpts) (string, error) {
+	var b []byte
+	var err error
+
+	if opts.NotesFile == "-" {
+		b, err = io.ReadAll(opts.IO.In)
+		_ = opts.IO.In.Close()
+	} else {
+		b, err = os.ReadFile(opts.NotesFile)
+	}
+
+	if err != nil {
+		return "", err
+	}
+
+	return string(b), nil
+}
+
+func resolveNotesFileOrText(opts *CreateOpts) (string, error) {
+	// Rules from: https://docs.gitlab.com/ee/ci/yaml/index.html#releasedescription
+
+	// Rule 1: A file path can't have spaces
+	if strings.Contains(strings.TrimSpace(opts.ExperimentalNotesTextOrFile), " ") {
+		return opts.ExperimentalNotesTextOrFile, nil
+	}
+
+	// Rule 2: A file must be relative to the repository
+	baseDir, err := os.Getwd()
+	if err != nil {
+		return "", err
+	}
+	filePath, err := securejoin.SecureJoin(baseDir, opts.ExperimentalNotesTextOrFile)
+	if err != nil {
+		return "", err
+	}
+
+	b, err := os.ReadFile(filePath)
+	if err != nil {
+		// Rule 3: fallback to using the value as text
+		return opts.ExperimentalNotesTextOrFile, nil
+	}
+
+	return string(b), nil
+}
+
 func createRun(opts *CreateOpts) error {
 	client, err := opts.HTTPClient()
 	if err != nil {
@@ -349,6 +433,10 @@ func createRun(opts *CreateOpts) error {
 		opts.IO.Logf("%s Release created:\t%s=%s\n", color.GreenCheck(),
 			color.Blue("url"), release.Links.Self)
 	} else {
+		if opts.NoUpdate {
+			return releaseFailedErr(fmt.Errorf("release for tag %q already exists and --no-update flag was specified", opts.TagName), start)
+		}
+
 		updateOpts := &gitlab.UpdateReleaseOptions{
 			Name: &opts.Name,
 		}
@@ -379,28 +467,37 @@ func createRun(opts *CreateOpts) error {
 		return releaseFailedErr(err, start)
 	}
 
-	if len(opts.Milestone) > 0 {
-		// close all associated milestones
-		for _, milestone := range opts.Milestone {
-			// run loading msg
-			opts.IO.StartSpinner("Closing milestone %q", milestone)
-			// close milestone
-			err := closeMilestone(opts, milestone)
-			// stop loading
-			opts.IO.StopSpinner("")
-			if err != nil {
-				opts.IO.Log(color.FailedIcon(), err.Error())
-			} else {
-				opts.IO.Logf("%s Closed milestone %q\n", color.GreenCheck(), milestone)
+	if opts.NoCloseMilestone {
+		opts.IO.Logf("%s Skipping closing milestones\n", color.GreenCheck())
+	} else {
+		if len(opts.Milestone) > 0 {
+			// close all associated milestones
+			for _, milestone := range opts.Milestone {
+				opts.IO.StartSpinner("Closing milestone %q", milestone)
+				err := closeMilestone(opts, milestone)
+				opts.IO.StopSpinner("")
+				if err != nil {
+					opts.IO.Log(color.FailedIcon(), err.Error())
+				} else {
+					opts.IO.Logf("%s Closed milestone %q\n", color.GreenCheck(), milestone)
+				}
 			}
 		}
 	}
-	opts.IO.Logf(color.Bold("%s Release succeeded after %0.2fs.\n"), color.GreenCheck(), time.Since(start).Seconds())
+	opts.IO.Logf(color.Bold("%s Release succeeded after %0.2f seconds.\n"), color.GreenCheck(), time.Since(start).Seconds())
+
+	if opts.PublishToCatalog {
+		err = catalog.Publish(opts.IO, client, repo.FullName(), release.TagName)
+		if err != nil {
+			return cmdutils.WrapError(err, "failed to publish the release to the GitLab CI/CD catalog.")
+		}
+	}
+
 	return nil
 }
 
 func releaseFailedErr(err error, start time.Time) error {
-	return cmdutils.WrapError(err, fmt.Sprintf("release failed after %0.2fs.", time.Since(start).Seconds()))
+	return cmdutils.WrapError(err, fmt.Sprintf("release failed after %0.2f seconds.", time.Since(start).Seconds()))
 }
 
 func getMilestoneByTitle(c *CreateOpts, title string) (*gitlab.Milestone, error) {
