@@ -14,7 +14,7 @@ import (
 func NewCmdRelease(f *cmdutils.Factory) *cobra.Command {
 	releaseCmd := &cobra.Command{
 		Use:   "release <command> [flags]",
-		Short: `Manage GitLab releases`,
+		Short: `Manage GitLab releases.`,
 		Long:  ``,
 	}
 
