@@ -16,7 +16,7 @@ import (
 	"gitlab.com/gitlab-org/cli/pkg/tableprinter"
 	"gitlab.com/gitlab-org/cli/pkg/utils"
 
-	"github.com/xanzy/go-gitlab"
+	gitlab "gitlab.com/gitlab-org/api/client-go"
 )
 
 func DisplayAllReleases(io *iostreams.IOStreams, releases []*gitlab.Release, repoName string) string {
