@@ -1,14 +1,13 @@
 package commands
 
 import (
-	"bytes"
-	"io"
 	"os"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
 	"gitlab.com/gitlab-org/cli/commands/cmdtest"
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
+	"gitlab.com/gitlab-org/cli/test"
 )
 
 func TestMain(m *testing.M) {
@@ -23,20 +22,9 @@ func TestRootVersion(t *testing.T) {
 	assert.Nil(t, rootCmd.Flag("version").Value.Set("true"))
 	assert.Nil(t, rootCmd.Execute())
 
-	outC := make(chan string)
-	// copy the output in a separate goroutine so printing can't block indefinitely
-	go func() {
-		var buf bytes.Buffer
-		_, _ = io.Copy(&buf, r)
-		outC <- buf.String()
-	}()
+	out := test.ReturnBuffer(old, r, w)
 
-	// back to normal state
-	w.Close()
-	os.Stdout = old // restoring the real stdout
-	out := <-outC
-
-	assert.Equal(t, "glab version 1.0.0 (2020-01-01)\n", out)
+	assert.Equal(t, "Current glab version: 1.0.0 (2020-01-01)\n", out)
 }
 
 func TestRootNoArg(t *testing.T) {
@@ -46,18 +34,8 @@ func TestRootNoArg(t *testing.T) {
 	rootCmd := NewCmdRoot(cmdutils.NewFactory(), "v1.0.0", "2020-01-01")
 	assert.Nil(t, rootCmd.Execute())
 
-	outC := make(chan string)
-	// copy the output in a separate goroutine so printing can't block indefinitely
-	go func() {
-		var buf bytes.Buffer
-		_, _ = io.Copy(&buf, r)
-		outC <- buf.String()
-	}()
+	out := test.ReturnBuffer(old, r, w)
 
-	// back to normal state
-	w.Close()
-	os.Stdout = old // restoring the real stdout
-	out := <-outC
 	assert.Contains(t, out, "GLab is an open source GitLab CLI tool that brings GitLab to your command line.\n")
 	assert.Contains(t, out, `USAGE
   glab <command> <subcommand> [flags]
