@@ -5,6 +5,7 @@ import (
 	scheduleDeleteCmd "gitlab.com/gitlab-org/cli/commands/schedule/delete"
 	scheduleListCmd "gitlab.com/gitlab-org/cli/commands/schedule/list"
 	scheduleRunCmd "gitlab.com/gitlab-org/cli/commands/schedule/run"
+	scheduleUpdateCmd "gitlab.com/gitlab-org/cli/commands/schedule/update"
 
 	"gitlab.com/gitlab-org/cli/commands/cmdutils"
 
@@ -25,6 +26,7 @@ func NewCmdSchedule(f *cmdutils.Factory) *cobra.Command {
 	scheduleCmd.AddCommand(scheduleRunCmd.NewCmdRun(f))
 	scheduleCmd.AddCommand(scheduleCreateCmd.NewCmdCreate(f))
 	scheduleCmd.AddCommand(scheduleDeleteCmd.NewCmdDelete(f))
+	scheduleCmd.AddCommand(scheduleUpdateCmd.NewCmdUpdate(f))
 
 	return scheduleCmd
 }
