@@ -21,10 +21,10 @@ func NewVariableCmd(f *cmdutils.Factory) *cobra.Command {
 	cmdutils.EnableRepoOverride(cmd, f)
 
 	cmd.AddCommand(setCmd.NewCmdSet(f, nil))
-	cmd.AddCommand(listCmd.NewCmdSet(f, nil))
-	cmd.AddCommand(deleteCmd.NewCmdSet(f, nil))
-	cmd.AddCommand(updateCmd.NewCmdSet(f, nil))
-	cmd.AddCommand(getCmd.NewCmdSet(f, nil))
+	cmd.AddCommand(listCmd.NewCmdList(f, nil))
+	cmd.AddCommand(deleteCmd.NewCmdDelete(f, nil))
+	cmd.AddCommand(updateCmd.NewCmdUpdate(f, nil))
+	cmd.AddCommand(getCmd.NewCmdGet(f, nil))
 	cmd.AddCommand(exportCmd.NewCmdExport(f, nil))
 	return cmd
 }
